@@ -1,9 +1,5 @@
-"""CLI utilities for vcspull.
+"""CLI utilities for vcspull."""
 
-vcspull.cli
-~~~~~~~~~~~
-
-"""
 import argparse
 import logging
 import textwrap
@@ -12,8 +8,9 @@ from typing import overload
 
 from libvcs.__about__ import __version__ as libvcs_version
 
-from ..__about__ import __version__
-from ..log import setup_logger
+from vcspull.__about__ import __version__
+from vcspull.log import setup_logger
+
 from .sync import create_sync_subparser, sync
 
 log = logging.getLogger(__name__)
@@ -28,20 +25,18 @@ SYNC_DESCRIPTION = textwrap.dedent(
       vcspull sync "django-*" flask
       vcspull sync -c ./myrepos.yaml "*"
       vcspull sync -c ./myrepos.yaml myproject
-"""
+""",
 ).strip()
 
 
 @overload
 def create_parser(
     return_subparsers: t.Literal[True],
-) -> tuple[argparse.ArgumentParser, t.Any]:
-    ...
+) -> tuple[argparse.ArgumentParser, t.Any]: ...
 
 
 @overload
-def create_parser(return_subparsers: t.Literal[False]) -> argparse.ArgumentParser:
-    ...
+def create_parser(return_subparsers: t.Literal[False]) -> argparse.ArgumentParser: ...
 
 
 def create_parser(
@@ -91,7 +86,7 @@ def cli(_args: t.Optional[list[str]] = None) -> None:
     if args.subparser_name is None:
         parser.print_help()
         return
-    elif args.subparser_name == "sync":
+    if args.subparser_name == "sync":
         sync(
             repo_patterns=args.repo_patterns,
             config=args.config,
