@@ -1,4 +1,5 @@
-"""Synchronization functionailty for vcspull."""
+"""Synchronization functionality for vcspull."""
+
 import argparse
 import logging
 import pathlib
@@ -12,8 +13,8 @@ from libvcs._internal.types import VCSLiteral
 from libvcs.sync.git import GitSync
 from libvcs.url import registry as url_tools
 
-from .. import exc
-from ..config import filter_repos, find_config_files, load_configs
+from vcspull import exc
+from vcspull.config import filter_repos, find_config_files, load_configs
 
 log = logging.getLogger(__name__)
 
@@ -79,19 +80,19 @@ def sync(
     found_repos = []
 
     for repo_pattern in repo_patterns:
-        dir, vcs_url, name = None, None, None
+        path, vcs_url, name = None, None, None
         if any(repo_pattern.startswith(n) for n in ["./", "/", "~", "$HOME"]):
-            dir = repo_pattern
+            path = repo_pattern
         elif any(repo_pattern.startswith(n) for n in ["http", "git", "svn", "hg"]):
             vcs_url = repo_pattern
         else:
             name = repo_pattern
 
         # collect the repos from the config files
-        found = filter_repos(configs, dir=dir, vcs_url=vcs_url, name=name)
+        found = filter_repos(configs, path=path, vcs_url=vcs_url, name=name)
         if len(found) == 0:
-            print(NO_REPOS_FOR_TERM_MSG.format(name=name))
-        found_repos.extend(filter_repos(configs, dir=dir, vcs_url=vcs_url, name=name))
+            log.info(NO_REPOS_FOR_TERM_MSG.format(name=name))
+        found_repos.extend(filter_repos(configs, path=path, vcs_url=vcs_url, name=name))
 
     for repo in found_repos:
         try:
