@@ -6,6 +6,7 @@ information from :class:`libvcs.base.RepoLoggingAdapter`.
 Colorized formatters for generic logging inside the application is also
 provided.
 """
+
 import logging
 import time
 import typing as t
@@ -90,9 +91,7 @@ class LogFormatter(logging.Formatter):
             " ",
         ]
 
-        tpl = "".join(reset + levelname + asctime + name + reset)
-
-        return tpl
+        return "".join(reset + levelname + asctime + name + reset)
 
     def __init__(self, color: bool = True, **kwargs: t.Any) -> None:
         logging.Formatter.__init__(self, **kwargs)
@@ -163,28 +162,20 @@ class DebugLogFormatter(LogFormatter):
             "%(lineno)d",
         ]
 
-        tpl = "".join(
+        return "".join(
             reset + levelname + asctime + name + module_funcName + lineno + reset,
         )
 
-        return tpl
-
 
 class RepoLogFormatter(LogFormatter):
-    """Log message from vcs repository."""
+    """Log message for VCS repository."""
 
     def template(self, record: logging.LogRecord) -> str:
         """Template for logging vcs bin name, along with a contextual hint."""
-        record.message = "".join(
-            [Fore.MAGENTA, Style.BRIGHT, record.message, Fore.RESET, Style.RESET_ALL],
-        )
-        return "{}|{}| {}({}) {}".format(
-            Fore.GREEN + Style.DIM,
-            record.bin_name,  # type:ignore
-            Fore.YELLOW,
-            record.keyword,  # type:ignore
-            Fore.RESET,
+        record.message = (
+            f"{Fore.MAGENTA}{Style.BRIGHT}{record.message}{Fore.RESET}{Style.RESET_ALL}"
         )
+        return f"{Fore.GREEN + Style.DIM}|{record.bin_name}| {Fore.YELLOW}({record.keyword}) {Fore.RESET}"  # type:ignore # noqa: E501
 
 
 class RepoFilter(logging.Filter):
