@@ -1,4 +1,5 @@
 """Utility functions for vcspull."""
+
 import os
 import pathlib
 import typing as t
@@ -68,5 +69,5 @@ def update_dict(
             r = update_dict(d.get(k, {}), v)
             d[k] = r
         else:
-            d[k] = u[k]
+            d[k] = v
     return d
